"use strict";
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_1 = require("@theia/core/shared/react");
var react_jss_1 = require("react-jss");
var constants_1 = require("../../constants");
var SingleValueContainer_1 = require("../SingleValueContainer");
var MetricWidgetContext_1 = require("../MetricWidgetContext");
var useStyles = react_jss_1.createUseStyles({
    innerContainer: {
        display: "flex",
        flexDirection: "column",
        padding: 24,
        width: "100%",
        justifyContent: "space-between",
    },
    outerContainer: {
        display: "flex",
        height: "128px",
        backgroundColor: "var(--theia-button-background)",
        color: "var(--theia-button-foreground)",
        "&:hover": {
            backgroundColor: "var(--theia-button-hoverBackground)",
        },
        overflow: "auto",
        borderRadius: "6px",
        cursor: "pointer",
    },
    label: {
        margin: 0,
        fontWeight: 600,
        color: "var(--theia-descriptionForeground)",
        fontSize: 18,
    },
    value: {
        margin: "0 0 0 auto",
        fontWeight: 600,
    },
    description: {
        margin: 0,
        color: "var(--theia-descriptionForeground)",
        fontSize: 16,
        overflow: "auto",
    },
    descriptionContainer: {
        padding: 24,
        width: "100%",
    },
});
var MetricWidget = function (props) {
    var _a;
    var widget = props.widget;
    var value_key = widget.value_key, metric_url = widget.metric_url, key_separator = widget.key_separator, response_format = widget.response_format, unit = widget.unit, fallback_value = widget.fallback_value;
    var classes = useStyles();
    var _b = __read(react_1.useState(false), 2), flipped = _b[0], setFlipped = _b[1];
    var _c = MetricWidgetContext_1.useMetricWidgetContext(), fetchMetricUrl = _c.fetchMetricUrl, getValueByKey = _c.getValueByKey, responseDict = _c.responseDict, globalResponse = _c.globalResponse, globalResponseFormat = _c.globalResponseFormat;
    react_1.useEffect(function () {
        fetchMetricUrl(widget.metric_url, widget.response_format);
    }, []);
    if (widget.type === constants_1.EMetricWidgetType.SINGLE_VALUE_CONTAINER) {
        return (React.createElement(SingleValueContainer_1.default, { widget: widget }, (_a = widget.widgets) === null || _a === void 0 ? void 0 : _a.map(function (widgetNode, index) { return (React.createElement(MetricWidget, { widget: widgetNode, key: widgetNode.title + "-" + index })); })));
    }
    var valueByKey = react_1.useMemo(function () {
        var val = getValueByKey({
            key: value_key,
            keySeparator: key_separator,
            metricUrl: metric_url,
            responseFormat: response_format,
        });
        if (val) {
            return val + " " + (unit || "");
        }
        return fallback_value;
    }, [
        JSON.stringify(globalResponse),
        JSON.stringify(responseDict),
        globalResponseFormat,
    ]);
    return (React.createElement("div", { className: classes.outerContainer, onClick: function () {
            return widget.description && setFlipped(function (prevState) { return !prevState; });
        } }, flipped ? (React.createElement("div", { className: classes.descriptionContainer },
        React.createElement("p", { className: classes.description }, widget.description))) : (React.createElement("div", { className: classes.innerContainer },
        React.createElement("p", { className: classes.label }, widget.title),
        React.createElement("p", { className: classes.value }, valueByKey)))));
};
exports.default = MetricWidget;
//# sourceMappingURL=MetricWidget.js.map