"use strict";
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.createGalileoMetricsWidgetPreferences = exports.GalileoMetricsWidgetPreferences = exports.galileoMetricsWidgetConfigurationSchema = void 0;
var inversify_1 = require("inversify");
var galileo_ide_metrics_dashboard_widget_widget_1 = require("./galileo-ide-metrics-dashboard-widget-widget");
var galileo_ide_metrics_dashboard_widget_contribution_1 = require("./galileo-ide-metrics-dashboard-widget-contribution");
var browser_1 = require("@theia/core/lib/browser");
require("../../src/browser/style/index.css");
exports.galileoMetricsWidgetConfigurationSchema = {
    $schema: "http://json-schema.org/draft-07/schema",
    $id: "http://example.com/example.json",
    type: "object",
    title: "The root schema",
    description: "The root schema comprises the entire JSON document.",
    default: {},
    examples: [
        {
            title: "Metrics Dashboard",
            metric_url: "http://localhost:8080/rpc/metrics",
            response_format: "prometheus",
            widgets: [
                {
                    title: "By the numbers",
                    type: "single_value_container",
                    widgets: [
                        {
                            title: "Total Incoming Connections",
                            value_key: "data/metrics/total_incoming_connections",
                            key_separator: "/",
                            type: "single_value",
                            description_key: "help",
                        },
                        {
                            title: "Avg. Inclusion Distance",
                            value_key: "avg_distance",
                            type: "single_value",
                            description: "Description to explain the metric.",
                            unit: "Slot(s)",
                        },
                        {
                            title: "Recent Epoch Gains",
                            value_key: "recent_epoch_gains",
                            type: "single_value",
                            description: "Description to explain the metric.",
                            unit: "ETH",
                        },
                        {
                            title: "Correctly Voted Head Percent",
                            value_key: "correctly_voted_head",
                            type: "single_value",
                            description: "Description to explain the metric.",
                            unit: "%",
                        },
                        {
                            title: "Validating Keys",
                            value_key: "validating_keys",
                            type: "single_value",
                            description: "Description to explain the metric.",
                            metric_url: "http://localhost:8080/rpc/metrics/validating-keys",
                            response_format: "json",
                        },
                    ],
                },
                {
                    title: "Chart Name",
                    value_keys: ["worst_validator", "avg_validator", "best_validator"],
                    description: "Description for chart",
                    type: "bar_chart",
                    x_axis_label: "X Axis Label",
                    y_axis_label: "Y Axis Label",
                    legend: [
                        {
                            key: "worst_validator",
                            label: "Worst performing validator",
                            color: "#696D84",
                        },
                        {
                            key: "avg_validator",
                            label: "Average performing validator",
                            color: "#979CB9",
                        },
                        {
                            key: "best_validator",
                            label: "Best performing validator",
                            color: "#BBC2E5",
                        },
                    ],
                },
            ],
        },
    ],
    required: ["title", "response_format", "widgets"],
    properties: (_a = {},
        _a["galileo.metrics.title" /* TITLE */] = {
            $id: "#/properties/title",
            type: "string",
            title: "The title schema",
            description: "The title of the Dashboard.",
            default: "",
            examples: ["Metrics Dashboard"],
        },
        _a["galileo.metrics.metric_url" /* METRIC_URL */] = {
            $id: "#/properties/metric_url",
            type: "string",
            title: "The metric_url schema",
            description: "The URL of the metrics, if this is provided in top level widget's value_key will be searched from this response (if no widget-specific metric_url provided).",
            default: "",
            examples: ["http://localhost:8080/rpc/metrics"],
        },
        _a["galileo.metrics.response_format" /* RESPONSE_FORMAT */] = {
            $id: "#/properties/response_format",
            type: "string",
            title: "The response_format schema",
            description: "Could be 'prometheus' or 'json'. According parser will be applied if 'prometheus'.",
            default: "",
            examples: ["prometheus, json"],
        },
        _a["galileo.metrics.widgets" /* WIDGETS */] = {
            $id: "#/properties/widgets",
            type: "array",
            title: "The widgets schema",
            description: "Widget array of the dashboard.",
            default: [],
            examples: [
                [
                    {
                        title: "By the numbers",
                        type: "single_value_container",
                        widgets: [
                            {
                                title: "Total Incoming Connections",
                                value_key: "data/metrics/total_incoming_connections",
                                key_separator: "/",
                                type: "single_value",
                                description_key: "help",
                            },
                            {
                                title: "Avg. Inclusion Distance",
                                value_key: "avg_distance",
                                type: "single_value",
                                description: "Description to explain the metric.",
                                unit: "Slot(s)",
                                fallback_value: "-",
                            },
                            {
                                title: "Recent Epoch Gains",
                                value_key: "recent_epoch_gains",
                                type: "single_value",
                                description: "Description to explain the metric.",
                                unit: "ETH",
                            },
                            {
                                title: "Correctly Voted Head Percent",
                                value_key: "correctly_voted_head",
                                type: "single_value",
                                description: "Description to explain the metric.",
                                unit: "%",
                            },
                            {
                                title: "Validating Keys",
                                value_key: "validating_keys",
                                type: "single_value",
                                description: "Description to explain the metric.",
                                metric_url: "http://localhost:8080/rpc/metrics/validating-keys",
                                response_format: "json",
                            },
                        ],
                    },
                    {
                        title: "Chart Name",
                        value_keys: ["worst_validator", "avg_validator", "best_validator"],
                        description: "Description for chart",
                        type: "bar_chart",
                        x_axis_label: "X Axis Label",
                        y_axis_label: "Y Axis Label",
                        legend: [
                            {
                                key: "worst_validator",
                                label: "Worst performing validator",
                                color: "#696D84",
                            },
                            {
                                key: "avg_validator",
                                label: "Average performing validator",
                                color: "#979CB9",
                            },
                            {
                                key: "best_validator",
                                label: "Best performing validator",
                                color: "#BBC2E5",
                            },
                        ],
                    },
                ],
            ],
            additionalItems: true,
            items: {
                $id: "#/properties/widgets/items",
                anyOf: [
                    {
                        $id: "#/properties/widgets/items/anyOf/0",
                        type: "object",
                        title: "The first anyOf schema",
                        description: "An explanation about the purpose of this instance.",
                        default: {},
                        examples: [
                            {
                                title: "By the numbers",
                                type: "single_value_container",
                                widgets: [
                                    {
                                        title: "Total Incoming Connections",
                                        value_key: "data/metrics/total_incoming_connections",
                                        key_separator: "/",
                                        type: "single_value",
                                        description_key: "help",
                                    },
                                    {
                                        title: "Avg. Inclusion Distance",
                                        value_key: "avg_distance",
                                        type: "single_value",
                                        description: "Description to explain the metric.",
                                        unit: "Slot(s)",
                                        fallback_value: "-",
                                    },
                                    {
                                        title: "Recent Epoch Gains",
                                        value_key: "recent_epoch_gains",
                                        type: "single_value",
                                        description: "Description to explain the metric.",
                                        unit: "ETH",
                                    },
                                    {
                                        title: "Correctly Voted Head Percent",
                                        value_key: "correctly_voted_head",
                                        type: "single_value",
                                        description: "Description to explain the metric.",
                                        unit: "%",
                                    },
                                    {
                                        title: "Validating Keys",
                                        value_key: "validating_keys",
                                        type: "single_value",
                                        description: "Description to explain the metric.",
                                        metric_url: "http://localhost:8080/rpc/metrics/validating-keys",
                                        response_format: "json",
                                    },
                                ],
                            },
                        ],
                        required: ["title", "type", "widgets"],
                        properties: {
                            title: {
                                $id: "#/properties/widgets/items/anyOf/0/properties/title",
                                type: "string",
                                title: "The title schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["By the numbers"],
                            },
                            type: {
                                $id: "#/properties/widgets/items/anyOf/0/properties/type",
                                type: "string",
                                title: "The type schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["single_value_container"],
                            },
                            widgets: {
                                $id: "#/properties/widgets/items/anyOf/0/properties/widgets",
                                type: "array",
                                title: "The widgets schema",
                                description: "An explanation about the purpose of this instance.",
                                default: [],
                                examples: [
                                    [
                                        {
                                            title: "Total Incoming Connections",
                                            value_key: "data/metrics/total_incoming_connections",
                                            key_separator: "/",
                                            type: "single_value",
                                            description_key: "help",
                                        },
                                        {
                                            title: "Avg. Inclusion Distance",
                                            value_key: "avg_distance",
                                            type: "single_value",
                                            description: "Description to explain the metric.",
                                            unit: "Slot(s)",
                                        },
                                    ],
                                ],
                                additionalItems: true,
                                items: {
                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items",
                                    anyOf: [
                                        {
                                            $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/0",
                                            type: "object",
                                            title: "The first anyOf schema",
                                            description: "An explanation about the purpose of this instance.",
                                            default: {},
                                            examples: [
                                                {
                                                    title: "Total Incoming Connections",
                                                    value_key: "total_incoming_connections",
                                                    type: "single_value",
                                                    description_key: "help",
                                                },
                                            ],
                                            required: [
                                                "title",
                                                "value_key",
                                                "type",
                                                "description_key",
                                            ],
                                            properties: {
                                                title: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/0/properties/title",
                                                    type: "string",
                                                    title: "The title schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["Total Incoming Connections"],
                                                },
                                                value_key: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/0/properties/value_key",
                                                    type: "string",
                                                    title: "The value_key schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["data/metrics/total_incoming_connections"],
                                                },
                                                key_separator: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/0/properties/key_separator",
                                                    type: "string",
                                                    title: "The key_separator schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["/"],
                                                },
                                                fallback_value: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/0/properties/fallback_value",
                                                    type: "string",
                                                    title: "The fallback_value schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["-"],
                                                },
                                                type: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/0/properties/type",
                                                    type: "string",
                                                    title: "The type schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["single_value"],
                                                },
                                                description_key: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/0/properties/description_key",
                                                    type: "string",
                                                    title: "The description_key schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["help"],
                                                },
                                            },
                                            additionalProperties: true,
                                        },
                                        {
                                            $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/1",
                                            type: "object",
                                            title: "The second anyOf schema",
                                            description: "An explanation about the purpose of this instance.",
                                            default: {},
                                            examples: [
                                                {
                                                    title: "Avg. Inclusion Distance",
                                                    value_key: "avg_distance",
                                                    type: "single_value",
                                                    description: "Description to explain the metric.",
                                                    unit: "Slot(s)",
                                                },
                                            ],
                                            required: [
                                                "title",
                                                "value_key",
                                                "type",
                                                "description",
                                                "unit",
                                            ],
                                            properties: {
                                                title: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/1/properties/title",
                                                    type: "string",
                                                    title: "The title schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["Avg. Inclusion Distance"],
                                                },
                                                value_key: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/1/properties/value_key",
                                                    type: "string",
                                                    title: "The value_key schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["avg_distance"],
                                                },
                                                type: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/1/properties/type",
                                                    type: "string",
                                                    title: "The type schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["single_value"],
                                                },
                                                description: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/1/properties/description",
                                                    type: "string",
                                                    title: "The description schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["Description to explain the metric."],
                                                },
                                                unit: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/1/properties/unit",
                                                    type: "string",
                                                    title: "The unit schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["Slot(s)"],
                                                },
                                            },
                                            additionalProperties: true,
                                        },
                                        {
                                            $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/2",
                                            type: "object",
                                            title: "The third anyOf schema",
                                            description: "An explanation about the purpose of this instance.",
                                            default: {},
                                            examples: [
                                                {
                                                    title: "Validating Keys",
                                                    value_key: "validating_keys",
                                                    type: "single_value",
                                                    description: "Description to explain the metric.",
                                                    metric_url: "http://localhost:8080/rpc/metrics/validating-keys",
                                                    response_format: "json",
                                                },
                                            ],
                                            required: [
                                                "title",
                                                "value_key",
                                                "type",
                                                "description",
                                                "metric_url",
                                                "response_format",
                                            ],
                                            properties: {
                                                title: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/2/properties/title",
                                                    type: "string",
                                                    title: "The title schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["Validating Keys"],
                                                },
                                                value_key: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/2/properties/value_key",
                                                    type: "string",
                                                    title: "The value_key schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["validating_keys"],
                                                },
                                                type: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/2/properties/type",
                                                    type: "string",
                                                    title: "The type schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["single_value"],
                                                },
                                                description: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/2/properties/description",
                                                    type: "string",
                                                    title: "The description schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["Description to explain the metric."],
                                                },
                                                metric_url: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/2/properties/metric_url",
                                                    type: "string",
                                                    title: "The metric_url schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: [
                                                        "http://localhost:8080/rpc/metrics/validating-keys",
                                                    ],
                                                },
                                                response_format: {
                                                    $id: "#/properties/widgets/items/anyOf/0/properties/widgets/items/anyOf/2/properties/response_format",
                                                    type: "string",
                                                    title: "The response_format schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["json"],
                                                },
                                            },
                                            additionalProperties: true,
                                        },
                                    ],
                                },
                            },
                        },
                        additionalProperties: true,
                    },
                    {
                        $id: "#/properties/widgets/items/anyOf/1",
                        type: "object",
                        title: "The second anyOf schema",
                        description: "An explanation about the purpose of this instance.",
                        default: {},
                        examples: [
                            {
                                title: "Chart Name",
                                value_keys: [
                                    "worst_validator",
                                    "avg_validator",
                                    "best_validator",
                                ],
                                description: "Description for chart",
                                type: "bar_chart",
                                x_axis_label: "X Axis Label",
                                y_axis_label: "Y Axis Label",
                                legend: [
                                    {
                                        key: "worst_validator",
                                        label: "Worst performing validator",
                                        color: "#696D84",
                                    },
                                    {
                                        key: "avg_validator",
                                        label: "Average performing validator",
                                        color: "#979CB9",
                                    },
                                    {
                                        key: "best_validator",
                                        label: "Best performing validator",
                                        color: "#BBC2E5",
                                    },
                                ],
                            },
                        ],
                        required: [
                            "title",
                            "value_keys",
                            "description",
                            "type",
                            "x_axis_label",
                            "y_axis_label",
                            "legend",
                        ],
                        properties: {
                            title: {
                                $id: "#/properties/widgets/items/anyOf/1/properties/title",
                                type: "string",
                                title: "The title schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["Chart Name"],
                            },
                            value_keys: {
                                $id: "#/properties/widgets/items/anyOf/1/properties/value_keys",
                                type: "array",
                                title: "The value_keys schema",
                                description: "An explanation about the purpose of this instance.",
                                default: [],
                                examples: [["worst_validator", "avg_validator"]],
                                additionalItems: true,
                                items: {
                                    $id: "#/properties/widgets/items/anyOf/1/properties/value_keys/items",
                                    anyOf: [
                                        {
                                            $id: "#/properties/widgets/items/anyOf/1/properties/value_keys/items/anyOf/0",
                                            type: "string",
                                            title: "The first anyOf schema",
                                            description: "An explanation about the purpose of this instance.",
                                            default: "",
                                            examples: ["worst_validator", "avg_validator"],
                                        },
                                    ],
                                },
                            },
                            description: {
                                $id: "#/properties/widgets/items/anyOf/1/properties/description",
                                type: "string",
                                title: "The description schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["Description for chart"],
                            },
                            type: {
                                $id: "#/properties/widgets/items/anyOf/1/properties/type",
                                type: "string",
                                title: "The type schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["bar_chart"],
                            },
                            x_axis_label: {
                                $id: "#/properties/widgets/items/anyOf/1/properties/x_axis_label",
                                type: "string",
                                title: "The x_axis_label schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["X Axis Label"],
                            },
                            y_axis_label: {
                                $id: "#/properties/widgets/items/anyOf/1/properties/y_axis_label",
                                type: "string",
                                title: "The y_axis_label schema",
                                description: "An explanation about the purpose of this instance.",
                                default: "",
                                examples: ["Y Axis Label"],
                            },
                            legend: {
                                $id: "#/properties/widgets/items/anyOf/1/properties/legend",
                                type: "array",
                                title: "The legend schema",
                                description: "An explanation about the purpose of this instance.",
                                default: [],
                                examples: [
                                    [
                                        {
                                            key: "worst_validator",
                                            label: "Worst performing validator",
                                            color: "#696D84",
                                        },
                                        {
                                            key: "avg_validator",
                                            label: "Average performing validator",
                                            color: "#979CB9",
                                        },
                                    ],
                                ],
                                additionalItems: true,
                                items: {
                                    $id: "#/properties/widgets/items/anyOf/1/properties/legend/items",
                                    anyOf: [
                                        {
                                            $id: "#/properties/widgets/items/anyOf/1/properties/legend/items/anyOf/0",
                                            type: "object",
                                            title: "The first anyOf schema",
                                            description: "An explanation about the purpose of this instance.",
                                            default: {},
                                            examples: [
                                                {
                                                    key: "worst_validator",
                                                    label: "Worst performing validator",
                                                    color: "#696D84",
                                                },
                                            ],
                                            required: ["key", "label", "color"],
                                            properties: {
                                                key: {
                                                    $id: "#/properties/widgets/items/anyOf/1/properties/legend/items/anyOf/0/properties/key",
                                                    type: "string",
                                                    title: "The key schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["worst_validator"],
                                                },
                                                label: {
                                                    $id: "#/properties/widgets/items/anyOf/1/properties/legend/items/anyOf/0/properties/label",
                                                    type: "string",
                                                    title: "The label schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["Worst performing validator"],
                                                },
                                                color: {
                                                    $id: "#/properties/widgets/items/anyOf/1/properties/legend/items/anyOf/0/properties/color",
                                                    type: "string",
                                                    title: "The color schema",
                                                    description: "An explanation about the purpose of this instance.",
                                                    default: "",
                                                    examples: ["#696D84"],
                                                },
                                            },
                                            additionalProperties: true,
                                        },
                                    ],
                                },
                            },
                        },
                        additionalProperties: true,
                    },
                ],
            },
        },
        _a),
    additionalProperties: true,
};
exports.GalileoMetricsWidgetPreferences = Symbol("GalileoMetricsWidgetPreferences");
function createGalileoMetricsWidgetPreferences(preferences) {
    return browser_1.createPreferenceProxy(preferences, exports.galileoMetricsWidgetConfigurationSchema);
}
exports.createGalileoMetricsWidgetPreferences = createGalileoMetricsWidgetPreferences;
exports.default = new inversify_1.ContainerModule(function (bind) {
    browser_1.bindViewContribution(bind, galileo_ide_metrics_dashboard_widget_contribution_1.GalileoIdeMetricsDashboardWidgetContribution);
    bind(browser_1.FrontendApplicationContribution).toService(galileo_ide_metrics_dashboard_widget_contribution_1.GalileoIdeMetricsDashboardWidgetContribution);
    bind(galileo_ide_metrics_dashboard_widget_widget_1.GalileoIdeMetricsDashboardWidgetWidget).toSelf();
    bind(browser_1.WidgetFactory)
        .toDynamicValue(function (ctx) { return ({
        id: galileo_ide_metrics_dashboard_widget_widget_1.GalileoIdeMetricsDashboardWidgetWidget.ID,
        createWidget: function () {
            return ctx.container.get(galileo_ide_metrics_dashboard_widget_widget_1.GalileoIdeMetricsDashboardWidgetWidget);
        },
    }); })
        .inSingletonScope();
    bind(exports.GalileoMetricsWidgetPreferences).toDynamicValue(function (ctx) {
        var preferences = ctx.container.get(browser_1.PreferenceService);
        return createGalileoMetricsWidgetPreferences(preferences);
    });
    bind(browser_1.PreferenceContribution).toConstantValue({
        schema: exports.galileoMetricsWidgetConfigurationSchema,
    });
});
//# sourceMappingURL=galileo-ide-metrics-dashboard-widget-frontend-module.js.map