import * as React from "react";
import { injectable, postConstruct, inject } from "inversify";
import { ReactWidget } from "@theia/core/lib/browser/widgets/react-widget";
import { deepClone, MessageService } from "@theia/core";
import { EResponseFormat, IMetricWidget } from "./constants";
import { PreferenceService } from "@theia/core/lib/browser";
import MetricWidget from "./components/MetricWidget";
import { MetricWidgetProvider } from "./components/MetricWidgetContext";

export interface Settings {
  title: string;
  metricUrl: string;
  responseFormat: EResponseFormat;
  widgets: IMetricWidget[];
}

@injectable()
export class GalileoIdeMetricsDashboardWidgetWidget extends ReactWidget {
  static readonly ID = "galileo-ide-metrics-dashboard-widget:widget";
  static readonly LABEL = "Metrics Dashboard";

  @inject(MessageService)
  protected readonly messageService!: MessageService;

  @inject(PreferenceService)
  protected readonly preferenceService: PreferenceService;
  protected _settings: Settings;

  @postConstruct()
  protected async init(): Promise<void> {
    this.id = GalileoIdeMetricsDashboardWidgetWidget.ID;
    this.title.label = GalileoIdeMetricsDashboardWidgetWidget.LABEL;
    this.title.caption = GalileoIdeMetricsDashboardWidgetWidget.LABEL;
    this.title.closable = true;
    const settings = await this.loadSettings();
    this._settings = deepClone(settings);

    this.update();
  }

  protected async loadSettings(): Promise<Settings> {
    await this.preferenceService.ready;
    const [title, metricUrl, responseFormat, widgets] = await Promise.all([
      this.preferenceService.get<string>("galileo.metrics.title", ""),
      this.preferenceService.get<string>("galileo.metrics.metric_url", ""),
      this.preferenceService.get<EResponseFormat>(
        "galileo.metrics.response_format",
        EResponseFormat.JSON
      ),
      this.preferenceService.get<Array<IMetricWidget>>(
        "galileo.metrics.widgets",
        []
      ),
    ]);
    return {
      title,
      metricUrl,
      responseFormat,
      widgets,
    };
  }

  protected render(): React.ReactNode {
    return (
      <div className="widget-container">
        <h1 className="title">{this._settings.title}</h1>
        <div className="metric-widget-container">
          <MetricWidgetProvider
            responseFormat={this._settings.responseFormat}
            metricUrl={this._settings.metricUrl}
          >
            {this._settings.widgets.map((widget, index) => (
              <MetricWidget widget={widget} key={`${widget.title}-${index}`} />
            ))}
          </MetricWidgetProvider>
        </div>
      </div>
    );
  }
}
